aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/nnn.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/nnn.c b/src/nnn.c
index 08899ee..de80d46 100644
--- a/src/nnn.c
+++ b/src/nnn.c
@@ -2588,7 +2588,7 @@ static int filterentries(char *path, char *lastname)
#endif
case 27: /* Exit filter mode on Escape and Alt+key */
if (handle_alt_key(ch) != ERR) {
- if (*ch == 27) { /* Handle Alt + Esc */
+ if (*ch == 13) { /* Handle Alt + Ret */
if (wln[1]) {
ln[REGEX_MAX - 1] = ln[1];
ln[1] = wln[1] = '\0';
@@ -4136,7 +4136,7 @@ static void show_help(const char *path)
"a1-4 Context 1-4%-7c(Sh)Tab Cycle context\n"
"c/ Filter%-17c^N Toggle type-to-nav\n"
"aEsc Exit prompt%-12c^L Redraw/clear prompt\n"
- "c0 Lock%-14cAlt+Esc Clear filter, redraw\n"
+ "c0 Lock%-14cAlt+Ret Clear filter, redraw\n"
"c? Help, conf%-13c^G QuitCD\n"
"cq Quit context%-7c^Q (Q) Quit (with err)\n"
"1FILES\n"